




log using nonparametric.txt, text replace

cd "/Users/lauramayoral/Dropbox/docum_dropbox/clases/econometrics III april 23/slides/Figures"

graph export "kernel4.pdf", replace
********** OVERVIEW OF nonparametric.do **********

*This STATA program combines information from several sources, including Cameron's do file

*(first part of the file)



*A. DENSITY ESTIMATION: HISTOGRAMS AND KERNELS

*************************************
*EXAMPLE 1: REAL DATA
*************************************



********** SETUP **********

clear all
set more off
version 15
set scheme s1mono  /* Graphics scheme */
set linesize 82

********** DATA DESCRIPTION **********

* The original data are from the PSID Individual Level Final Release 1993 data
* From www.isr.umich.edu/src/psid  then choose Data Center 
* 4856 observations on 9 variables for Females 30 to 50 years 
* See mma09p1np.do for further description

******* OLS WITH DOCTOR VISITS DATA

* Read in data, select, describe and summarize key variables
use nonparametric.dta, clear
describe 

* Work with age 36 and nonmissing education data
keep if age == 36
drop if educatn == .
summarize

******* KERNEL DENSITY ESTIMATE

* Histogram
histogram lnhwage
histogram lnhwage, bin(30) scale(1.1)
* graph export nonparametricfig1.wmf, replace

* Kernel density 
kdensity lnhwage
kdensity lnhwage, bw(0.21)
graph twoway (kdensity lnhwage, bw(0.21))  ///
  (kdensity lnhwage, bw(0.07) clstyle(p2)) ///
  (kdensity lnhwage, bw(0.63) clstyle(p3)), legend( label(1 "Default") ///
  label(2 "Half default") label(3 "Twice default") ) scale(1.1)
* graph export nonparametricfig2.wmf, replace

* Histogram and kernel density
histogram lnhwage, kdensity  

* Kernel density and normal density with data mean and standard deviation
kdensity lnhwage, normal




*************************************
*EXAMPLE 2: SIMULATED DATA
*************************************


clear all
set seed -7
set obs 200
gen x = 5*uniform()+5
gen y = 2 + sin(x) + 0.25*rnormal()
la var y "hours per day"
la var x "wage"
hist y, graphregion(color(white))
graph export "hist1.pdf", replace
hist y, bin(30) graphregion(color(white))
graph export "hist2.pdf", replace
hist y, bin(5) graphregion(color(white))
graph export "hist3.pdf", replace

twoway (hist y, graphregion(color(white))) ///
|| (kdensity y, graphregion(color(white)) lwidth(thick))
graph export "kernel_hist.pdf", replace
twoway (kdensity y, epan legend(label(1 Epanechnikov)) lcolor(red) lw(thick)) ///
|| (kdensity y, rectangle legend(label(2 Rectangle)) lpattern(dash) lw(thick) ///
lcolor(dkgreen)) ///
|| (kdensity y, gaussian legend(label(3 Gaussian)) lcolor(dknavy)) ///
, graphregion(color(white))
graph export "kernel_comparison.pdf", replace
twoway ///
|| (kdensity y, lwidth(thick) legend(label(1 "bandwidth = 0.21"))) ///
|| (kdensity y, bw(.80) legend(label(2 "bandwidth = 0.80"))) ///
|| (kdensity y, bw(.05) legend(label(3 "bandwidth = 0.05"))) ///
, graphregion(color(white)) xtitle(hourly wage)

graph export "kernel3.pdf", replace
kdensity y, normal graphregion(color(white)) lwidth(thick)
graph export "kernel4.pdf", replace
